package cz.muni.fi.pa165.addressbook;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.Statement;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

public class ExampleData {
    
    Connection connection = null;
    Statement statement = null;
    
    private ExampleData() throws SQLException, NamingException {
	DataSource dataSource = (DataSource) new InitialContext().
		lookup("java:comp/env/jdbc/addressbook");
	connection = dataSource.getConnection();
	statement = connection.createStatement();
    }
    
    private void close() {
	try {
	    if (statement != null) {
		statement.close();
		statement = null;
	    }
	} catch (SQLException ex) {
	    ex.printStackTrace();
	}
	try {
	    if (connection != null) {
		connection.close();
		connection = null;
	    }
	} catch (SQLException ex) {
	    ex.printStackTrace();
	}
    }
    
    protected void finalize() throws Throwable {
	close();
	super.finalize();
    }
    
    private boolean trySelectData() {
	try {
	    statement.executeQuery("SELECT id,name,address FROM person");
	    statement.executeQuery("SELECT personId,number,description FROM phoneNumber");
	    return true;
	} catch (SQLException ex) {
	    return false;
	}
    }
    
    private void execute(String sql) throws SQLException {
	statement.executeUpdate(sql);
    }
    
    
    public static void createExampleData() {
	
	ExampleData generator = null;
	try {
	    generator = new ExampleData();
	    if (!generator.trySelectData()) {
		
		generator.execute("CREATE TABLE person (" +
			"id int NOT NULL, " +
			"name varchar(100), " +
			"address varchar(100)," +
			"PRIMARY KEY (id));");
		generator.execute("CREATE TABLE phoneNumber (" +
			"personId int NOT NULL, " +
			"number char(20) NOT NULL, " +
			"description varchar(100)," +
			"PRIMARY KEY (personId,number));");
		
		generator.execute("INSERT INTO person values (1,'Jan Pavlovič','Neznámá 28, Brno')");
		generator.execute("INSERT INTO person values (2,'Petr Adámek','Botanická 68a, Brno')");
		generator.execute("INSERT INTO person values (3,'Pavel Drášil','Botanická 68a, Brno')");
		generator.execute("INSERT INTO person values (4,'Tomáš Pitner','Krásná 1111, Brno')");

		generator.execute("INSERT INTO phoneNumber values (1,'123 456789','Tajné číslo domů')");
		generator.execute("INSERT INTO phoneNumber values (1,'777 001001','Mobil')");
		generator.execute("INSERT INTO phoneNumber values (2,'777 123456','Mobil')");
		generator.execute("INSERT INTO phoneNumber values (1,'549 491810','Společné číslo do školy')");
		generator.execute("INSERT INTO phoneNumber values (2,'549 491810','Společné číslo do školy')");
		generator.execute("INSERT INTO phoneNumber values (3,'549 491810','Společné číslo do školy')");
		generator.execute("INSERT INTO phoneNumber values (4,'549 491810','Společné číslo do školy')");
	    }
	} catch (NamingException ex) {
	    throw new RuntimeException("Cannot create example data",ex);
	} catch (SQLException ex) {
	    throw new RuntimeException("Cannot create example data",ex);
	} finally {
	    if (generator != null) {
		generator.close();
	    }
	}
    }
    
}
